@@ -10,6 +10,7 @@ use {
     rayon::prelude::*,
     solana_core::{
         banking_stage::{BankingStage, BankingStageStats},
+        leader_slot_banking_stage_metrics::LeaderSlotMetricsTracker,
         qos_service::QosService,
     },
     solana_entry::entry::{next_hash, Entry},
@@ -98,6 +99,7 @@ fn bench_consume_buffered(bencher: &mut Bencher) {
                 &BankingStageStats::default(),
                 &recorder,
                 &Arc::new(QosService::new(Arc::new(RwLock::new(CostModel::default())))),
+                &mut LeaderSlotMetricsTracker::new(0),
             );
         });
 
